<?php
require_once 'db_config.php';

// Enable MySQLi error reporting for debugging
mysqli_report(MYSQLI_REPORT_ERROR | MYSQLI_REPORT_STRICT);

// Create connection
$conn = new mysqli($host, $user, $pass, $db);

// Check connection
if ($conn->connect_error) {
    echo json_encode(["error" => "Connection failed: " . $conn->connect_error]);
    exit;
}

// Fetch query parameters
$code_article = trim($_GET['code_article'] ?? null);
$size_code = trim($_GET['size_code'] ?? null);
$code_color = trim($_GET['code_color'] ?? null);

$debug_logs = [];

if (!$code_article || !$size_code || !$code_color) {
    $debug_logs[] = "Missing required parameters";
    echo json_encode(["error" => "Missing required parameters", "debug" => $debug_logs]);
    exit;
}

// Log parameters for debugging
$debug_logs[] = "Parameters: code_article={$code_article}, size_code={$size_code}, code_color={$code_color}";

// SQL query to fetch data based on code_article, old_code_article, size_code, and code_color
$sql = "
SELECT 
    p.plan AS plan,
    p.code_article AS product_code,
    p.name AS product_name,
    p.marque AS brand,
    c.code_color AS code_color,
    c.color AS color_name,
    s.code AS size_code,
    comp.name AS region,
    comp.compositions AS components,
    comp.instructions AS instructions,
    l.num_commande_client AS client_command,
    p.price_floor,
    p.price_ceparator,
    p.old_code_article,
    p.price_decimal,
    p.currency,
    t.name AS template_name,
    t.num_pages AS num_pages,
    t.path AS template_path
FROM products p
LEFT JOIN product_color pc ON p.id = pc.product_id
LEFT JOIN colors c ON pc.color_id = c.id
LEFT JOIN product_size ps ON p.id = ps.product_id
LEFT JOIN sizes s ON ps.size_id = s.id
LEFT JOIN labels l ON p.id = l.product_id
LEFT JOIN composition comp ON p.region_id = comp.id
LEFT JOIN templates t ON p.template_id = t.id
WHERE (p.code_article = ? OR p.old_code_article = ?)
AND (s.code = ? OR s.code IS NULL)
AND (c.code_color = ? OR c.code_color IS NULL)
";

$stmt = $conn->prepare($sql);
if (!$stmt) {
    $debug_logs[] = "Failed to prepare SQL statement";
    echo json_encode(["error" => "Failed to prepare SQL statement", "debug" => $debug_logs]);
    exit;
}

// Bind parameters and log query for debugging
$stmt->bind_param("ssss", $code_article, $code_article, $size_code, $code_color);
$debug_logs[] = "Executing query: {$sql} with parameters: code_article={$code_article}, size_code={$size_code}, code_color={$code_color}";

// Execute the statement and fetch the result
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $data = $result->fetch_assoc();

    // Parse components field
if (!empty($data['components'])) {
    $components = explode(';', $data['components']);
    foreach ($components as $index => $component) {
        $component_parts = explode(':', $component);
        $name = $component_parts[0] ?? 'Unknown Component';
        $percentage = $component_parts[1] ?? 'N/A';
        $data["p_component" . ($index + 1)] = trim($name);
        $data["component" . ($index + 1)] = trim($percentage);
    }
}



// Remove raw components field
unset($data['components']);



    // Output the data as JSON
    echo json_encode(["data" => $data, "debug" => $debug_logs]);
} else {
    // Log intermediate results for debugging
    $debug_logs[] = "No data found. Checking intermediate results.";

    // Check if the product exists
    $product_check_sql = "SELECT * FROM products WHERE code_article = ? OR old_code_article = ?";
    $product_check_stmt = $conn->prepare($product_check_sql);
    $product_check_stmt->bind_param("ss", $code_article, $code_article);
    $product_check_stmt->execute();
    $product_check_result = $product_check_stmt->get_result();
    if ($product_check_result->num_rows > 0) {
        $debug_logs[] = "Product found: " . json_encode($product_check_result->fetch_assoc());
    } else {
        $debug_logs[] = "Product not found.";
    }

    // Check if the size exists
    $size_check_sql = "SELECT * FROM sizes WHERE code = ?";
    $size_check_stmt = $conn->prepare($size_check_sql);
    $size_check_stmt->bind_param("s", $size_code);
    $size_check_stmt->execute();
    $size_check_result = $size_check_stmt->get_result();
    if ($size_check_result->num_rows > 0) {
        $debug_logs[] = "Size found: " . json_encode($size_check_result->fetch_assoc());
    } else {
        $debug_logs[] = "Size not found.";
    }

    // Check if the color exists
    $color_check_sql = "SELECT * FROM colors WHERE code_color = ?";
    $color_check_stmt = $conn->prepare($color_check_sql);
    $color_check_stmt->bind_param("s", $code_color);
    $color_check_stmt->execute();
    $color_check_result = $color_check_stmt->get_result();
    if ($color_check_result->num_rows > 0) {
        $debug_logs[] = "Color found: " . json_encode($color_check_result->fetch_assoc());
    } else {
        $debug_logs[] = "Color not found.";
    }

    // Check intermediate join results
    $intermediate_sql = "
    SELECT 
        p.id AS product_id,
        pc.color_id AS color_id,
        ps.size_id AS size_id
    FROM products p
    LEFT JOIN product_color pc ON p.id = pc.product_id
    LEFT JOIN product_size ps ON p.id = ps.product_id
    WHERE (p.code_article = ? OR p.old_code_article = ?)
    ";
    $intermediate_stmt = $conn->prepare($intermediate_sql);
    $intermediate_stmt->bind_param("ss", $code_article, $code_article);
    $intermediate_stmt->execute();
    $intermediate_result = $intermediate_stmt->get_result();
    if ($intermediate_result->num_rows > 0) {
        while ($row = $intermediate_result->fetch_assoc()) {
            $debug_logs[] = "Intermediate result: " . json_encode($row);
        }
    } else {
        $debug_logs[] = "No intermediate results found.";
    }

    echo json_encode(["error" => "No data found", "debug" => $debug_logs]);
}

// Close statement and connection
$stmt->close();
$conn->close();
?>
